==> FormsTutorial-1.0.tgz: FormsTutorial/formstutorial/controllers.py <==
import locale

from datetime import datetime

from turbogears import controllers, expose, error_handler, validate
from turbogears import flash, redirect, url
from turbogears import widgets, validators

# set the locale so that we can show the date in local format
locale.setlocale(locale.LC_ALL, '')

class Comments(list):
    """A very simple storage class for comments."""

    def add(self, name, email, text):
        self.append((name, email, text, datetime.now()))

# instantiate the storage object
comments = Comments()

class CommentFields(widgets.WidgetsList):
    """The WidgetsList defines the fields of the form."""

    name = widgets.TextField(validator=validators.NotEmpty())
    email = widgets.TextField(validator=validators.Email(not_empty=True),
                              attrs={'size':30})
    comment = widgets.TextArea(validator=validators.NotEmpty())
    notify = widgets.CheckBox(label="Notify me")

# The form is instantiated. We use the generic TableForm widget
# that displays every contained form widget in a table row
# and puts a sumbmit button at the bottom.
#
# The 'action' parameter determines the 'action' attribute of the
# form element in the generated HTML.
comment_form = widgets.TableForm(
    fields=CommentFields(),
    action="save"
)

class Root(controllers.RootController):

    @expose(template='.templates.index')
    def index(self):
        """Display a list of saved comments."""

        return dict(comments=comments)

    @expose(template='.templates.add')
    def add(self, tg_errors=None):
        """Show the comment form."""

        if tg_errors:
            flash('There was a problem with the form!')
        return dict(form=comment_form)

    @expose()
    @validate(form=comment_form)
    @error_handler(add)
    def save(self, name, email, comment, notify=False):
        """Handle submission from the comment form and save the comment."""

        comments.add(name, email, comment)
        if notify:
            flash('Comment added! You will be notified.')
        else:
            flash('Comment added!')
        redirect(url('/'))

==> FormsTutorial-1.1.tgz: FormsTutorial/formstutorial/controllers.py <==
import locale

from datetime import datetime

from turbogears import (controllers, error_handler, expose, flash,
    redirect, url, validate, validators, widgets)


# set the locale so that we can show the date in local format
locale.setlocale(locale.LC_ALL, '')


class Comments(list):
    """A very simple storage class for comments."""

    def add(self, name, email, text):
        self.append((name, email, text, datetime.now()))

# instantiate the storage object
comments = Comments()


class CommentFields(widgets.WidgetsList):
    """The WidgetsList defines the fields of the form."""

    name = widgets.TextField(validator=validators.NotEmpty())
    email = widgets.TextField(validator=validators.Email(not_empty=True),
                                attrs=dict(size=30))
    comment = widgets.TextArea(validator=validators.NotEmpty())
    notify = widgets.CheckBox(label="Notify me")


# The form is instantiated. We use the generic TableForm widget
# that displays every contained form widget in a table row
# and puts a submit button at the bottom.
#
# The 'action' parameter determines the 'action' attribute of the
# form element in the generated HTML.
comment_form = widgets.TableForm(
    fields=CommentFields(),
    action="save"
)


class Root(controllers.RootController):
    """The root controller of the application."""

    @expose(template='formstutorial.templates.index')
    def index(self):
        """Display a list of saved comments."""
        return dict(comments=comments)

    @expose(template='formstutorial.templates.add')
    def add(self, tg_errors=None):
        """Show the comment form."""
        if tg_errors:
            flash('There was a problem with the form!')
        return dict(form=comment_form)

    @expose()
    @validate(form=comment_form)
    @error_handler(add)
    def save(self, name, email, comment, notify=False):
        """Handle submission from the comment form and save the comment."""
        comments.add(name, email, comment)
        if notify:
            flash('Comment added! You will be notified.')
        else:
            flash('Comment added!')
        redirect(url('/'))
